@@ -1,7 +1,7 @@
 import warnings
 from django.conf import settings
 from django.conf.urls.defaults import patterns, url
-from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
+from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned, ValidationError
 from django.core.urlresolvers import NoReverseMatch, reverse, resolve, Resolver404
 from django.db.models.sql.constants import QUERY_TERMS, LOOKUP_SEP
 from django.http import HttpResponse, HttpResponseNotFound
@@ -48,6 +48,7 @@ class ResourceOptions(object):
     cache = NoCache()
     throttle = BaseThrottle()
     validation = Validation()
+    paginator_class = Paginator
     allowed_methods = ['get', 'post', 'put', 'delete']
     list_allowed_methods = None
     detail_allowed_methods = None
@@ -183,6 +184,8 @@ class Resource(object):
                 return response
             except (BadRequest, ApiFieldError), e:
                 return HttpBadRequest(e.args[0])
+            except ValidationError, e:
+                return HttpBadRequest(', '.join(e.messages))
             except Exception, e:
                 if hasattr(e, 'response'):
                     return e.response
@@ -614,7 +617,7 @@ class Resource(object):
             if field_object.attribute:
                 value = field_object.hydrate(bundle)
                 
-                if value is not None:
+                if value is not None or field_object.null:
                     # We need to avoid populating M2M data here as that will
                     # cause things to blow up.
                     if not getattr(field_object, 'is_related', False):
@@ -751,6 +754,29 @@ class Resource(object):
         
         return object_list
     
+    def can_create(self):
+        """
+        Checks to ensure ``post`` is within ``allowed_methods``.
+        """
+        allowed = set(self._meta.list_allowed_methods + self._meta.detail_allowed_methods)
+        return 'post' in allowed
+    
+    def can_update(self):
+        """
+        Checks to ensure ``put`` is within ``allowed_methods``.
+        
+        Used when hydrating related data.
+        """
+        allowed = set(self._meta.list_allowed_methods + self._meta.detail_allowed_methods)
+        return 'put' in allowed
+    
+    def can_delete(self):
+        """
+        Checks to ensure ``delete`` is within ``allowed_methods``.
+        """
+        allowed = set(self._meta.list_allowed_methods + self._meta.detail_allowed_methods)
+        return 'delete' in allowed
+    
     def obj_get_list(self, request=None, **kwargs):
         """
         Fetches the list of objects available on the resource.
@@ -908,8 +934,7 @@ class Resource(object):
         objects = self.obj_get_list(request=request, **self.remove_api_resource_names(kwargs))
         sorted_objects = self.apply_sorting(objects, options=request.GET)
         
-        paginator = Paginator(request.GET, sorted_objects, resource_uri=self.get_resource_list_uri(),
-           limit=self._meta.limit)
+        paginator = self._meta.paginator_class(request.GET, sorted_objects, resource_uri=self.get_resource_list_uri(), limit=self._meta.limit)
         to_be_serialized = paginator.page()
         
         # Dehydrate the bundles in preparation for serialization.
